@@ -125,7 +125,6 @@ pref("mailnews.headers.showSender", false);
 // Mail server preferences, pop by default
 // 0 pop, 1 imap; (Unix only:) 2 movemail, 3 inbox.
 pref("mail.server_type", 0);
-pref("mail.auth_login", true);
 
 pref("mail.default_drafts", "");    // empty string use default Drafts name;
 pref("mail.default_templates", ""); // empty string use default Templates name
@@ -196,7 +195,7 @@ pref("mail.file_attach_binary",             false);
 pref("mail.show_headers",                   1); // some
 pref("mail.pane_config.dynamic",            0);
 pref("mail.addr_book.mapit_url.format", "chrome://messenger-region/locale/region.properties");
-//@line 209 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 208 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
 
 // the format for "mail.addr_book.quicksearchquery.format" is:
 // @V == the escaped value typed in the quick search bar in the addressbook
@@ -222,7 +221,6 @@ pref("mail.compose.autosaveinterval", 5); // in minutes
 pref("mail.fcc_folder",                     "");
 
 pref("mail.default_html_action", 0);          // 0=ask, 1=plain, 2=html, 3=both
-pref("mail.smtp.ssl", 0);                     // 0 = no, 1 = try, 2 = must use SSL
 
 pref("mail.mdn.report.not_in_to_cc", 2);               // 0: Never 1: Always 2: Ask me
 pref("mail.mdn.report.outside_domain", 2);             // 0: Never 1: Always 2: Ask me
@@ -379,7 +377,7 @@ pref("mailnews.customDBHeaders", "");
 // close standalone message window when deleting the displayed message
 pref("mail.close_message_window.on_delete", false);
 
-//@line 394 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 392 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
 
 pref("mailnews.open_window_warning", 10); // warn user if they attempt to open more than this many messages at once
 
@@ -429,7 +427,7 @@ pref("mail.identity.default.headers", "");
 
 // by default, only collect addresses the user sends to (outgoing)
 // incoming is all spam anyways
-//@line 447 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 445 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
 pref("mail.collect_email_address_outgoing", true);
 
 // by default, use the Collected Addressbook for collection
@@ -437,6 +435,9 @@ pref("mail.collect_addressbook", "moz-abmdbdirectory://history.mab");
 
 pref("mail.default_sendlater_uri", "mailbox://nobody@Local%20Folders/Unsent%20Messages");
 
+pref("mail.smtpservers", "");
+pref("mail.accountmanager.accounts", "");
+
 pref("mail.server.default.port", -1);
 pref("mail.server.default.offline_support_level", -1);
 pref("mail.server.default.leave_on_server", false);
@@ -447,13 +448,12 @@ pref("mail.server.default.num_days_to_leave_on_server", 7);
 pref("mail.server.default.dot_fix", true);
 pref("mail.server.default.limit_offline_message_size", false);
 pref("mail.server.default.max_size", 50);
-pref("mail.server.default.auth_login", true);
 pref("mail.server.default.delete_mail_left_on_server", false);
 pref("mail.server.default.valid", true);
 pref("mail.server.default.abbreviate", true);
 pref("mail.server.default.isSecure", false);
-pref("mail.server.default.useSecAuth", false);
-pref("mail.server.default.socketType", 0);
+pref("mail.server.default.authMethod", 3); // cleartext password. @see nsIMsgIncomingServer.authMethod.
+pref("mail.server.default.socketType", 0); // @see nsIMsgIncomingServer.socketType
 pref("mail.server.default.override_namespaces", true);
 pref("mail.server.default.deferred_to_account", "");
 
@@ -481,7 +481,6 @@ pref("mail.server.default.login_at_startup", false);
 pref("mail.server.default.allows_specialfolders_usage", true);
 pref("mail.server.default.canCreateFolders", true);
 pref("mail.server.default.canFileMessages", true);
-pref("mail.server.default.logon_fallback", true);
 
 // special enhancements for IMAP servers
 pref("mail.server.default.is_gmail", false);
@@ -516,6 +515,7 @@ pref("mail.server.default.offline_download",true);
 pref("mail.server.default.autosync_max_age_days", -1);
 
 pref("mail.server.default.archive_granularity", 1);
+pref("mail.server.default.archive_keep_folder_structure", false);
 // the probablilty threshold over which messages are classified as junk
 // this number is divided by 100 before it is used. The classifier can be fine tuned
 // by changing this pref. Typical values are .99, .95, .90, .5, etc.
@@ -552,10 +552,8 @@ pref("mail.smtp.useMatchingDomainServer", false);
 // matching username and host name
 pref("mail.smtp.useMatchingHostNameServer", false);
 
-pref("mail.smtpserver.default.auth_method", 1); // auth any
-pref("mail.smtpserver.default.useSecAuth", false);
-pref("mail.smtpserver.default.trySecAuth", true);
-pref("mail.smtpserver.default.try_ssl", 0);
+pref("mail.smtpserver.default.authMethod", 3); // cleartext password. @see nsIMsgIncomingServer.authMethod.
+pref("mail.smtpserver.default.try_ssl", 0); // @see nsISmtpServer.socketType
 
 // For the next 3 prefs, see <http://www.bucksch.org/1/projects/mozilla/16507>
 pref("mail.display_glyph", true);   // TXT->HTML :-) etc. in viewer
@@ -669,7 +667,12 @@ pref("mail.biff.animate_dock_icon", false);
 // add jitter to biff interval
 pref("mail.biff.add_interval_jitter", true);
 
-//@line 690 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 688 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
+
+// If true, the number used in the Mac OS X dock notification will be the
+// the number of "new" messages, as per the classic Thunderbird definition.
+// Defaults to false, which notifies about the number of unread messages.
+pref("mail.biff.use_new_count_in_mac_dock", false);
 
 // Content disposition for attachments (except binary files and vcards).
 //   0= Content-Disposition: inline
@@ -693,10 +696,10 @@ pref("mailnews.use_received_date", false);
 pref("mail.ui.folderpane.version", 1);
 
 // for manual upgrades of certain UI features.
-//@line 716 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 719 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
 // Thunderbird uses this pref in msgMail3PaneWindow.js for bad reasons.
 pref("mailnews.ui.threadpane.version", 7);
-//@line 719 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 722 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
 // for manual upgrades of certain UI features.
 // 1 -> 2 is for the ab results pane tree landing
 // to hide the non default columns in the addressbook dialog
@@ -781,7 +784,7 @@ pref("mailnews.import.text.skipfirstrecord", true);
 // automatically scale attached images that are displayed inline
 pref("mail.enable_automatic_image_resizing", true);
 
-//@line 818 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 821 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
 pref("mail.check_new_mail", true);
 pref("mail.signature_file", "~/.signature");
 pref("mailnews.reply_with_extra_lines", 0);
@@ -790,23 +793,25 @@ pref("news.cache_xover", false);
 pref("news.show_first_unread", false);
 pref("news.sash_geometry", "");
 pref("mail.signature_date", 0);
-//@line 830 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 833 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
 
 // gtk2 (*nix) lacks transparent/translucent drag support (bug 376238), so we
 // want to disable it so people can see where they are dragging things.
 // (Stock gtk drag icons will be used instead.)
-//@line 835 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 838 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
 pref("nglayout.enable_drag_images", false);
-//@line 837 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 840 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
 
-//@line 841 "/buildbot/comm-central-linux-nightly/build/mailnews/mailnews.js"
+//@line 844 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/mailnews.js"
 
 // For the Empty Junk/Trash confirmation dialogs.
 pref("mailnews.emptyJunk.dontAskAgain", false);
 pref("mailnews.emptyTrash.dontAskAgain", false);
 
 // where to fetch auto config information from.
-pref("mailnews.auto_config_url", "https://live.mozillamessaging.com/autoconfig/");
+pref("mailnews.auto_config_url", "https://live.mozillamessaging.com/autoconfig/v1.1/");
+// Added in bug 551519. Remove when bug 545866 is fixed.
+pref("mailnews.mx_service_url", "https://live.mozillamessaging.com/dns/mx/");
 
 // -- Summary Database options
 // dontPreserveOnCopy: a space separated list of properties that are not
