@@ -101,6 +101,8 @@ function initCopiesAndFolder(identity)
   document.getElementById('identity.archivesFolderPickerMode').value = copiesAndFoldersIdentity.archivesFolderPickerMode ? copiesAndFoldersIdentity.archivesFolderPickerMode : 0;
   document.getElementById('identity.tmplFolderPickerMode').value = copiesAndFoldersIdentity.tmplFolderPickerMode ? copiesAndFoldersIdentity.tmplFolderPickerMode : 0;
 
+  document.getElementById('identity.doCc').checked = copiesAndFoldersIdentity.doCc;
+  document.getElementById('identity.doCcList').value = copiesAndFoldersIdentity.doCcList;
   document.getElementById('identity.doBcc').checked = copiesAndFoldersIdentity.doBcc;
   document.getElementById('identity.doBccList').value = copiesAndFoldersIdentity.doBccList;
   document.getElementById('identity.doFcc').checked = copiesAndFoldersIdentity.doFcc;
@@ -116,7 +118,7 @@ function initCompositionAndAddressing(identity)
 
   document.getElementById('identity.directoryServer').value = addressingIdentity.directoryServer;
   document.getElementById('identity.overrideGlobal_Pref').value = addressingIdentity.overrideGlobalPref;
-//@line 122 "/buildbot/comm-central-linux-nightly/build/mailnews/base/prefs/content/am-identity-edit.js"
+//@line 124 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/base/prefs/content/am-identity-edit.js"
   document.getElementById('identity.composeHtml').checked = addressingIdentity.composeHtml;
   document.getElementById('identity.autoQuote').checked = addressingIdentity.autoQuote;
   document.getElementById('identity.replyOnTop').value = addressingIdentity.replyOnTop;
@@ -230,6 +232,8 @@ function saveCopiesAndFolderSettings(identity)
   identity.draftsFolderPickerMode = document.getElementById('identity.draftsFolderPickerMode').value;
   identity.archivesFolderPickerMode = document.getElementById('identity.archivesFolderPickerMode').value;
   identity.tmplFolderPickerMode = document.getElementById('identity.tmplFolderPickerMode').value;
+  identity.doCc = document.getElementById('identity.doCc').checked;
+  identity.doCcList = document.getElementById('identity.doCcList').value;
   identity.doBcc = document.getElementById('identity.doBcc').checked;
   identity.doBccList = document.getElementById('identity.doBccList').value;
   identity.doFcc = document.getElementById('identity.doFcc').checked;
@@ -241,7 +245,7 @@ function saveAddressingAndCompositionSettings(identity)
 {
   identity.directoryServer = document.getElementById('identity.directoryServer').value;
   identity.overrideGlobalPref = document.getElementById('identity.overrideGlobal_Pref').value == "true";
-//@line 249 "/buildbot/comm-central-linux-nightly/build/mailnews/base/prefs/content/am-identity-edit.js"
+//@line 253 "/buildbot/linux-comm-1.9.2-nightly/build/mailnews/base/prefs/content/am-identity-edit.js"
   identity.composeHtml = document.getElementById('identity.composeHtml').checked;
   identity.autoQuote = document.getElementById('identity.autoQuote').checked;
   identity.replyOnTop = document.getElementById('identity.replyOnTop').value;
